@@ -582,3 +582,12 @@ function faces(::Rect3)
         (3, 4, 8, 7), (1, 3, 7, 5), (6, 8, 4, 2)
     ]
 end
+
+function Extents.extent(rect::Rect2)
+    (xmin, ymin), (xmax, ymax) = extrema(rect)
+    return Extents.Extent(X=(xmin, xmax), Y=(ymin, ymax))
+end
+function Extents.extent(rect::Rect3)
+    (xmin, ymin, zmin), (xmax, ymax, zmax) = extrema(rect)
+    return Extents.Extent(X=(xmin, xmax), Y=(ymin, ymax), Z=(zmin, zmax))
+end
